#ifndef _FILESYS_H_
#define _FILESYS_H_

#include <qdict.h>
#include <qstring.h>
#include "sensor.h"

class MntData {
 public:
	MntData(const char* fsname, const char* dir, 
		const char* type, const char* opts, 
		unsigned long _total, unsigned long _used, unsigned long _free,
		unsigned long _avail,
		unsigned long _total_inode, unsigned long _used_inode, unsigned long _free_inode,
		unsigned long _used_percent, unsigned long _free_percent);
	QString mnt_fsname;    /* name of mounted file system */
	QString mnt_dir;       /* file system path prefix */
	QString mnt_type;      /* mount type (see mntent.h) */
	QString mnt_opts;      /* mount options (see mntent.h) */
	unsigned long total, used, free; /* M */  
	unsigned long avail;
	unsigned long total_inode, used_inode, free_inode; /* inode */  
	unsigned long used_percent, free_percent; /* % */
};

class ProcessorSensor;

class FilesysSensor : public Sensor {
public:
	FilesysSensor();
	virtual ~FilesysSensor();
	virtual QString query(const QString& instance, const QString& pin);

	DECLARE_ACCESS_FUNC(total);
	DECLARE_ACCESS_FUNC(used);
	DECLARE_ACCESS_FUNC(free);
	DECLARE_ACCESS_FUNC(avail);
	DECLARE_ACCESS_FUNC(total_inode);
	DECLARE_ACCESS_FUNC(used_inode);
	DECLARE_ACCESS_FUNC(free_inode);
	DECLARE_ACCESS_FUNC(used_percent);
	DECLARE_ACCESS_FUNC(free_percent);

	virtual int sample();
	void print();
	virtual QValueList<QString>& get_instances();
private:
	int build_instances();
	void print_mnt(MntData* m);
 	QDict<MntData> mnt;      /* current load */
	ProcessorSensor* ps;
};

#endif /* _FILESYS_H_ */
