#ifndef _NETWORK_H_
#define _NETWORK_H_

#include <qdict.h>
#include "sensor.h"

class NetLoadData {
public:
        NetLoadData(const QString& name);
	NetLoadData(const NetLoadData& ld);
	/* received */
        unsigned long rx_bytes, rx_packets, rx_errs, rx_drop;
	unsigned long rx_fifo, rx_frame, rx_compressed, rx_multicast;
	/* sent */
	unsigned long tx_bytes, tx_packets, tx_errs, tx_drop;
	unsigned long tx_fifo, tx_colls, tx_carrier, tx_compressed;
	/* rate */
	unsigned long rx_bytes_rate, rx_packets_rate;
	unsigned long tx_bytes_rate, tx_packets_rate;
	/* sample time, used to compute rate */
	unsigned long jiffies;
	QString ifname; /* interface name, e.g. eth0 */
	void clear();
	NetLoadData& operator+=(const NetLoadData& ld);
};

class ProcessorSensor;

class NetworkSensor : public Sensor {
public:
	NetworkSensor();
	virtual ~NetworkSensor();
	virtual QString query(const QString& instance, const QString& pin);
	DECLARE_ACCESS_FUNC(rx_bytes);
	DECLARE_ACCESS_FUNC(rx_packets); 
	DECLARE_ACCESS_FUNC(rx_errs); 
	DECLARE_ACCESS_FUNC(rx_drop);
	DECLARE_ACCESS_FUNC(rx_fifo); 
	DECLARE_ACCESS_FUNC(rx_frame); 
	DECLARE_ACCESS_FUNC(rx_compressed); 
	DECLARE_ACCESS_FUNC(rx_multicast);
	DECLARE_ACCESS_FUNC(tx_bytes); 
	DECLARE_ACCESS_FUNC(tx_packets); 
	DECLARE_ACCESS_FUNC(tx_errs); 
	DECLARE_ACCESS_FUNC(tx_drop);
	DECLARE_ACCESS_FUNC(tx_fifo); 
	DECLARE_ACCESS_FUNC(tx_colls); 
	DECLARE_ACCESS_FUNC(tx_carrier); 
	DECLARE_ACCESS_FUNC(tx_compressed);
	DECLARE_ACCESS_FUNC(rx_bytes_rate);
	DECLARE_ACCESS_FUNC(rx_packets_rate);
	DECLARE_ACCESS_FUNC(tx_bytes_rate);
	DECLARE_ACCESS_FUNC(tx_packets_rate);
	virtual int sample();
	void print();
private:
	int if_nr;             /* interface total number */
	int sample_load();
	QDict<NetLoadData> pre_load;  /* previous load */
 	QDict<NetLoadData> load;      /* current load */
	ProcessorSensor* ps;
};

#endif /* _NETWORK_H_ */
