#ifndef _PROCESSOR_H_
#define _PROCESSOR_H_

#include "sensor.h"

#define MAX_IRQ 256

class CPULoadData {
public:
        CPULoadData();
        unsigned long user, system, total, intr_total;
	unsigned long intr[MAX_IRQ];
	unsigned long process_count;
	unsigned long ctxt; /* context switch */
	void sum_intr();
};


class ProcessorSensor : public Sensor {
public:
	ProcessorSensor();
	virtual ~ProcessorSensor();
	virtual QString query(const QString& instance, const QString& pin);
	unsigned long user_time(int instance);	        /* % User Time */
	unsigned long system_time(int instance);	/* % System Time */
	unsigned long processor_time(int instance);	/* % Processor Time */
	unsigned long interrupt_rate(int instance);	/* Interrupts/sec */
	unsigned long process_count(int instance);	/* Process Count */
	unsigned long ctxt(int instance);	        /* Context Switch */
	unsigned long ctxt_rate(int instance);	        /* Context Switch/sec */	       

	virtual int sample();
	void print();
	unsigned long jiffies();
private:
	int cpu_nr;             /* CPU total number */
	int sample_load();
	int sample_intr();
	CPULoadData* pre_load;  /* previous load */
 	CPULoadData* load;      /* current load */
};

extern "C" {
	Sensor* create_sensor_processor();
}
#endif /* _PROCESSOR_H_ */
